@@ -10,6 +10,8 @@ class WaybackError(Exception):
     Raised when Waybackpy can not return what you asked for.
      1) Wayback Machine API Service is unreachable/down.
      2) You passed illegal arguments.
+
+     All other exceptions are inherited from this class.
     """
 
 
@@ -36,3 +38,15 @@ class MaximumSaveRetriesExceeded(MaximumRetriesExceeded):
     """
     MaximumSaveRetriesExceeded
     """
+
+
+class ArchiveNotInAvailabilityAPIResponse(WaybackError):
+    """
+    Could not parse the archive in the JSON response of the availability API.
+    """
+
+
+class InvalidJSONInAvailabilityAPIResponse(WaybackError):
+    """
+    availability api returned invalid JSON
+    """
